@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 from itertools import chain
-from functools import partial
+from functools import partial, wraps
 
-from clu.constants.consts import λ
-from clu.constants.polyfills import unicode
+from clu.constants.consts import λ, φ, pytuple, QUALIFIER
 from clu.enums import alias
 from clu.exporting import Exporter
 
@@ -12,8 +11,10 @@ exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 # PREDICATE LOGIC: negate(function) will “negate” a boolean predicate function –
+assigned = pytuple('doc', 'annotations')
+wrap = lambda function: wraps(function, assigned=assigned)
 
-negate = lambda function: (lambda *args, **kwargs: not function(*args, **kwargs))
+negate = lambda function: wrap(function)(lambda *args, **kwargs: not function(*args, **kwargs))
 
 negate_doc = """
 ### … You use `negate(function)` thusly:
@@ -47,10 +48,14 @@ isclass = lambda thing: (thing is object) or (hasattr(thing, '__mro__') and \
 isclasstype = lambda thing: hasattr(thing, '__mro__') and \
                                     thing.__mro__[-1] is object
 
+metaclass = lambda thing: ismetaclass(thing) and thing \
+                          or (isclass(thing) and type(thing) \
+                          or (type(type(thing))))
+
 # PREDICATE FUNCTIONS: hasattr(…) shortcuts:
 
 noattr = lambda thing, atx: negate(hasattr)(thing, atx)
-haspyattr = lambda thing, atx: hasattr(thing, '__%s__' % atx)
+haspyattr = lambda thing, atx: hasattr(thing, f'__{atx}__')
 nopyattr = lambda thing, atx: negate(haspyattr)(thing, atx)
 
 anyattrs = lambda thing, *attrs: any(hasattr(thing, atx) for atx in attrs)
@@ -77,25 +82,56 @@ nuhuh = lambda thing: None
 
 no_op     = lambda thing, atx, default=None: thing
 or_none   = lambda thing, atx: getattr(thing, atx, None)
-getpyattr = lambda thing, atx, default=None: getattr(thing, '__%s__' % atx, default)
-getitem   = lambda thing, itx, default=None: getattr(thing, 'get', no_op)(itx, default)
+getpyattr = lambda thing, atx, default=None: getattr(thing, f'__{atx}__', default)
+
+getitem   = lambda thing, itx, default=None: thing.__contains__(itx) \
+                                         and thing.__getitem__(itx) \
+                                          or default
+
+@export
+def resolve(thing, atx):
+    """ resolve(thing, atx) → retrieve and resolve an attribute, following
+        each dotted segment, back from its host thing.
+        
+        Q.v. the standard library “operator” module notes supra.:
+            https://docs.python.org/3/library/operator.html#operator.attrgetter
+    """
+    for atn in atx.split(QUALIFIER):
+        thing = or_none(thing, atn)
+    return thing
 
 accessor = lambda function, thing, *attrs, default=None: ([atx for atx in (function(thing, atx) \
                                                                for atx in attrs) \
                                                                 if atx is not None] or [default]).pop(0)
 
+acquirer = lambda function, thing, *attrs, default=tuple(): tuple(atx for atx in (function(thing, atx) \
+                                                                      for atx in attrs) \
+                                                                       if atx is not None) or default
+
 searcher = lambda function, xatx, *things, default=None: ([atx for atx in (function(thing, xatx) \
                                                                for thing in things) \
                                                                 if atx is not None] or [default]).pop(0)
 
-attr   = lambda thing, *attrs, default=None: accessor(or_none,   thing, *attrs, default=default)
-pyattr = lambda thing, *attrs, default=None: accessor(getpyattr, thing, *attrs, default=default)
-item   = lambda thing, *items, default=None: accessor(getitem,   thing, *items, default=default)
+collator = lambda function, xatx, *things, default=tuple(): tuple(atx for atx in (function(thing, xatx) \
+                                                                      for thing in things) \
+                                                                       if atx is not None) or default
 
-attr_search   = lambda atx, *things, default=None: searcher(or_none,   atx, *things, default=default)
+attr     = lambda thing, *attrs, default=None: accessor(resolve,   thing, *attrs, default=default)
+pyattr   = lambda thing, *attrs, default=None: accessor(getpyattr, thing, *attrs, default=default)
+item     = lambda thing, *items, default=None: accessor(getitem,   thing, *items, default=default)
+
+attrs    = lambda thing, *attrs, default=tuple(): acquirer(resolve,   thing, *attrs, default=default)
+pyattrs  = lambda thing, *attrs, default=tuple(): acquirer(getpyattr, thing, *attrs, default=default)
+items    = lambda thing, *items, default=tuple(): acquirer(getitem,   thing, *items, default=default)
+
+attr_search   = lambda atx, *things, default=None: searcher(resolve,   atx, *things, default=default)
 pyattr_search = lambda atx, *things, default=None: searcher(getpyattr, atx, *things, default=default)
 item_search   = lambda itx, *things, default=None: searcher(getitem,   itx, *things, default=default)
 
+attr_across   = lambda atx, *things, default=tuple(): collator(resolve,   atx, *things, default=default)
+pyattr_across = lambda atx, *things, default=tuple(): collator(getpyattr, atx, *things, default=default)
+item_across   = lambda itx, *things, default=tuple(): collator(getitem,   itx, *things, default=default)
+
 # ENUM PREDICATES: `isenum(…)` predicate; `enumchoices(…)` to return a tuple
 # of strings naming an enum’s choices (like duh)
 
@@ -123,20 +159,19 @@ hasaliases = lambda thing: isenum(thing) and haspyattr(thing, 'aliases')
 predicate_nop = lambda *things: None
 function_nop = lambda iterable: None
 
-uncallable = lambda thing: negate(callable)(thing)
+uncallable = negate(callable)
 pyname = lambda thing: pyattr(thing, 'qualname', 'name')
 
 isexpandable = lambda thing: isinstance(thing, (tuple, list, set, frozenset,
                                                 map, filter, reversed) or isenum(thing))
 
-isnormative = lambda thing: isinstance(thing, (str, unicode, bytes, bytearray))
+isnormative = lambda thing: isinstance(thing, (str, bytes, bytearray))
 iscontainer = lambda thing: isiterable(thing) and \
                         not isnormative(thing) and \
                         not isclasstype(thing)
 
 # This is the equivalent of a lambda types’ built-in __repr__ function:
-lambda_repr = lambda instance, default=λ: "<function %s at 0x%0x>" % (pyattr(instance, 'qualname', 'name',
-                                                                             default=default),
+lambda_repr = lambda instance, default=λ: "<function %s at 0x%0x>" % (pyname(instance) or default,
                                                                           id(instance))
 
 class Partial(partial):
@@ -147,18 +182,28 @@ class Partial(partial):
     """
     
     def __init__(self, *args, **kwargs):
-        """ Initialize a new Partial object """
+        """ Initialize a new Partial object, with a predicate and a function """
         # N.B. The real action seems to happen in partial.__new__(…)
-        # Name the Partial instance, as if it’s a lambda-type:
-        self.__name__ = self.__qualname__ = λ
+        # Name the Partial instance, as if it’s a phi-type:
+        self.__name__ = self.__qualname__ = φ
         try:
             super(Partial, self).__init__(*args, **kwargs)
         except:
             super(Partial, self).__init__()
     
+    @property
+    def predicate(self):
+        """ Return the “predicate” argument with which this Partial was initialized """
+        return (len(self.args) > 0) and self.args[0] or None
+    
+    @property
+    def function(self):
+        """ Return the “function” argument with which this Partial was initialized """
+        return (len(self.args) > 1) and self.args[1] or None
+    
     def __repr__(self):
-        # Use the lambda_repr equivalent:
-        return lambda_repr(self)
+        # Use the lambda_repr equivalent, with a phi-type default name:
+        return lambda_repr(self, default=φ)
 
 @export
 def apply_to(predicate, function, *things):
@@ -168,7 +213,7 @@ def apply_to(predicate, function, *things):
         
             function(predicate(thing) for thing in things)
         
-        apply_to(predicate, function) → Return a partial† function ƒ(*things)
+        apply_to(predicate, function) → Return a Partial† function ƒ(*things)
         that will behave as `apply_to(predicate, function, *things)` when it
         is called as above.
         
@@ -191,14 +236,15 @@ def apply_to(predicate, function, *things):
     return function(predicate(thing) for thing in things)
 
 # Variadics:
-predicate_all = lambda predicate, *things: apply_to(predicate, all, *things)
-predicate_any = lambda predicate, *things: apply_to(predicate, any, *things)
+predicate_all  = lambda predicate, *things: apply_to(predicate, all,         *things)
+predicate_any  = lambda predicate, *things: apply_to(predicate, any,         *things)
+predicate_none = lambda predicate, *things: apply_to(predicate, negate(any), *things)
 
 # Booleans:
-predicate_and = lambda predicate, a, b: apply_to(predicate, all, a, b)
-predicate_or  = lambda predicate, a, b: apply_to(predicate, any, a, b)
-predicate_xor = lambda predicate, a, b: apply_to(predicate, any, a, b) and \
-                                    not apply_to(predicate, all, a, b)
+predicate_and  = lambda predicate, a, b: apply_to(predicate, all, a, b)
+predicate_or   = lambda predicate, a, b: apply_to(predicate, any, a, b)
+predicate_xor  = lambda predicate, a, b: apply_to(predicate, any, a, b) and \
+                                     not apply_to(predicate, all, a, b)
 
 # Does a thing or a class contain an attribute --
 # whether it uses `__dict__` or `__slots__` (or both)?
@@ -266,6 +312,7 @@ export(negate,          name='negate',          doc="negate(function) → Negate
 export(ismetaclass,     name='ismetaclass',     doc="ismetaclass(thing) → boolean predicate, True if thing is a metaclass, descending directly from `type`")
 export(isclass,         name='isclass',         doc="isclass(thing) → boolean predicate, True if thing is a class, descending from `object` but not `type`")
 export(isclasstype,     name='isclasstype',     doc="isclasstype(thing) → boolean predicate, True if thing is a class type, descending from either `object` or `type`")
+export(metaclass,       name='metaclass',       doc="metaclass(thing) → Returns: a) thing, if thing is a metaclass; b) type(thing), if thing is a class; or c) type(type(thing)), for all other instances")
 
 export(noattr,          name='noattr',          doc="noattr(thing, attribute) → boolean predicate, shortcut for `(not hasattr(thing, attribute))`")
 export(haspyattr,       name='haspyattr',       doc="haspyattr(thing, attribute) → boolean predicate, shortcut for `hasattr(thing, '__%s__' % attribute)`")
@@ -290,14 +337,22 @@ export(or_none,         name='or_none',         doc="or_none(thing, attribute) 
 export(getpyattr,       name='getpyattr',       doc="getpyattr(thing, attribute[, default]) → shortcut for `getattr(thing, '__%s__' % attribute[, default])`")
 export(getitem,         name='getitem',         doc="getitem(thing, item[, default]) → shortcut for `thing.get(item[, default])`")
 export(accessor,        name='accessor',        doc="accessor(func, thing, *attributes) → return the first non-None value had by successively applying func(thing, attribute) to all attributes")
-export(searcher,        name='searcher',        doc="searcher(func, attribute, *things) → return the first non-None value had by successively applying func(thing, attribute) to all things")
+export(acquirer,        name='acquirer',        doc="acquirer(func, thing, *attributes) → return all of the non-None values had by successively applying func(thing, attribute) to all attributes")
+export(searcher,        name='searcher',        doc="searcher(func, attribute, *things) → return the first non-None value had by successively applying func(thing, attribute) sequentially to all things")
+export(collator,        name='collator',        doc="collator(func, attribute, *things) → return all of the non-None values had by successively applying func(thing, attribute) across all things")
 
 export(attr,            name='attr',            doc="attr(thing, *attributes) → Return the first existing attribute from `thing`, given 1+ attribute names")
 export(pyattr,          name='pyattr',          doc="pyattr(thing, *attributes) → Return the first existing __special__ attribute from `thing`, given 1+ attribute names")
 export(item,            name='item',            doc="item(thing, *itemnames) → Return the first existing item held by `thing`, given 1+ item names")
+export(attrs,           name='attrs',           doc="attrs(thing, *attributes) → Return all of the existing named attributes from `thing`, given 1+ attribute names")
+export(pyattrs,         name='pyattrs',         doc="pyattrs(thing, *attributes) → Return all of the existing named __special__ attributes from `thing`, given 1+ attribute names")
+export(items,           name='items',           doc="items(thing, *itemnames) → Return all of the existing named items held by `thing`, given 1+ item names")
 export(attr_search,     name='attr_search',     doc="attr_search(attribute, *things) → Return the first-found existing attribute from a thing, given 1+ things")
 export(pyattr_search,   name='pyattr_search',   doc="pyattr_search(attribute, *things) → Return the first-found existing __special__ attribute from a thing, given 1+ things")
 export(item_search,     name='item_search',     doc="item_search(itemname, *things) → Return the first-found existing item from a thing, given 1+ things")
+export(attr_across,     name='attr_across',     doc="attr_across(attribute, *things) → Return all of the existing named attributes across all things (given 1+ things)")
+export(pyattr_across,   name='pyattr_across',   doc="pyattr_across(attribute, *things) → Return all of the existing named __special__ attributes across all things (given 1+ things)")
+export(item_across,     name='item_across',     doc="item_across(attribute, *things) → Return all of the existing named items held across all things (given 1+ things)")
 
 export(isaliasdescriptor,                       name='isaliasdescriptor',
                                                 doc="isaliasdescriptor(thing) → boolean predicate, returns True if `thing` is an aliasing descriptor bound to an existing Enum member")
@@ -317,6 +372,7 @@ export(lambda_repr,     name='lambda_repr',     doc="lambda_repr(instance) → E
 
 export(predicate_all,   name='predicate_all',   doc="predicate_all(predicate, *things) → boolean predicate, shortcut for `apply_to(predicate, all, *things)`")
 export(predicate_any,   name='predicate_any',   doc="predicate_any(predicate, *things) → boolean predicate, shortcut for `apply_to(predicate, any, *things)`")
+export(predicate_none,  name='predicate_none',  doc="predicate_none(predicate, *things) → boolean predicate, shortcut for `apply_to(predicate, negate(any), *things)`")
 export(predicate_and,   name='predicate_and',   doc="predicate_and(predicate, a, b) → boolean predicate, shortcut for `apply_to(predicate, all, a, b)`")
 export(predicate_or,    name='predicate_or',    doc="predicate_or(predicate, a, b) → boolean predicate, shortcut for `apply_to(predicate, any, a, b)`")
 export(predicate_xor,   name='predicate_xor',   doc="predicate_xor(predicate, a, b) → boolean predicate, shortcut for `apply_to(predicate, any, a, b) and not apply_to(predicate, all, a, b)`")
