@@ -117,8 +117,5 @@ export(types,           name='types',       doc=""" A Namespace instance contain
                                                     more typographically pleasing, like definitively.
                                                 """)
 
-export(SimpleNamespace)
-export(Namespace)
-
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
