@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
-from clu.constants import Nondeterminism
+from clu.constants.exceptions import Nondeterminism
 
 import pytest
 
@@ -49,36 +49,26 @@ class TestNaming(object):
         assert px1 == path_to_prefix(pp, end="≠")
         assert px2 == path_to_prefix(pp, sep="•", end="≠")
     
-    @pytest.mark.xfail
+    @pytest.mark.nondeterministic
     def test_qualified_name_constants(self):
         """ » Checking “qualified_name(¬) on items from clu.constants …” """
-        
-        from clu.constants.consts import BASEPATH, HOSTNAME, PROJECT_NAME, VERBOTEN
+        from clu.constants.consts import (BASEPATH, HOSTNAME, VERBOTEN, SCRIPT_PATH, TEST_PATH)
         from clu.naming import qualified_name
         
-        qname = qualified_name(VERBOTEN)
-        try:
-            assert qname == 'clu.constants.consts.VERBOTEN'
-        except AssertionError:
-            raise Nondeterminism(f"Nondeterminism in qualified_name(VERBOTEN) → {qname}")
+        names = ('BASEPATH', 'HOSTNAME', 'VERBOTEN', 'SCRIPT_PATH', 'TEST_PATH')
+        consts = (BASEPATH, HOSTNAME, VERBOTEN, SCRIPT_PATH, TEST_PATH)
         
-        qname = qualified_name(PROJECT_NAME)
-        try:
-            assert qname == 'clu.constants.consts.PROJECT_NAME'
-        except AssertionError:
-            raise Nondeterminism(f"Nondeterminism in qualified_name(PROJECT_NAME) → {qname}")
+        for name, const in zip(names, consts):
+            qname = qualified_name(const)
+            assert qname == f'clu.constants.consts.{name}'
         
-        qname = qualified_name(HOSTNAME)
-        try:
-            assert qname == 'clu.constants.consts.HOSTNAME'
-        except AssertionError:
-            raise Nondeterminism(f"Nondeterminism in qualified_name(HOSTNAME) → {qname}")
-        
-        qname = qualified_name(BASEPATH)
-        try:
-            assert qname == 'clu.constants.consts.BASEPATH'
-        except AssertionError:
-            raise Nondeterminism(f"Nondeterminism in qualified_name(BASEPATH) → {qname}")
+        """ This commented-out bit fails because “clu.__title__” (defined in clu/__init__.py)
+            is the same string – and interning makes them into the same object. """
+        # qname = qualified_name(PROJECT_NAME)
+        # try:
+        #     assert qname == 'clu.constants.consts.PROJECT_NAME'
+        # except AssertionError:
+        #     raise Nondeterminism(f"Nondeterminism in qualified_name(PROJECT_NAME) → {qname}")
     
     def test_qualified_name_instances(self):
         """ » Checking “qualified_name(¬) on instances of objects …” """
@@ -126,6 +116,8 @@ class TestNaming(object):
         except AssertionError:
             raise Nondeterminism(f"Nondeterminism in qualified_name(types) → {qname}")
     
+    @pytest.mark.nondeterministic
+    @pytest.mark.filterwarnings("ignore::DeprecationWarning")
     def test_qualified_import(self):
         """ » Checking “qualified_import(¬) …” """
         from clu.naming import qualified_import, qualified_name
@@ -174,31 +166,30 @@ class TestNaming(object):
         except AssertionError:
             raise Nondeterminism(f"Nondeterminism in qualified_name(Weight) → {qname}")
     
-    def _test_determine_module(self):
+    @pytest.mark.nondeterministic
+    def test_determine_module_failure_rate(self, clumods):
         """ » Checking `determine_module(…)` against `pickle.whichmodule(…)` …"""
-        
+        from clu.exporting import Exporter
         from clu.naming import determine_module
-        from clu.exporting import exporter
-        
         import pickle
+        
+        total = 0
         mismatches = 0
-        # print_separator()
+        modulenames = Exporter.modulenames()
         
-        for name, thing in exporter.exports().items():
-            # clade = Clade.of(thing, name_hint=name)
-            determination = determine_module(thing)
-            whichmodule = pickle.whichmodule(thing, None)
-            try:
-                assert determination == whichmodule
-            except AssertionError:
-                mismatches += 1
-                # print(f"»»» Module-lookup mismatch for {clade.to_string()} “{name}”")
-                # print(f"»»»   determine_module(…) → {determination}")
-                # print(f"»»» pickle.whichmodule(…) → {whichmodule}")
-                # print()
+        assert len(clumods) == len(modulenames)
         
-        # print(f"≠≠≠ TOTAL EXPORTED THING COUNT: {len(exporter)}")
-        # print(f"≠≠≠ TOTAL MISMATCHES FOUND: {mismatches!s}")
-        # print_separator()
-        # print()
-    
\ No newline at end of file
+        for modulename in modulenames:
+            exports = Exporter[modulename].exports()
+            total += len(exports)
+            for name, thing in exports.items():
+                whichmodule = pickle.whichmodule(thing, None)
+                determination = determine_module(thing)
+                try:
+                    assert determination == whichmodule
+                except AssertionError:
+                    mismatches += 1
+        
+        # In practice the failure rate seemed to be around 7.65 %
+        failure_rate = 100 * (float(mismatches) / float(total))
+        assert failure_rate < 8.0 # percent
